@@ -42,11 +42,6 @@
 
 #define MOON_PHASES 36
 
-/* g_memmove is removed in glib 2.40 */
-#if GLIB_CHECK_VERSION (2, 39, 0) && !defined(g_memmove)
-#define g_memmove memmove
-#endif
-
 /**
  * SECTION:weather
  * @Title: weather
@@ -593,7 +588,7 @@ weather_info_clone (const WeatherInfo *info)
 
 
     /* move everything */
-    g_memmove (clone, info, sizeof (WeatherInfo));
+    memmove (clone, info, sizeof (WeatherInfo));
 
 
     /* special moves */
